@@ -124,7 +124,13 @@ distanceMatrix <- function(sequences = NULL,
     `%dopar%` <- foreach::`%dopar%`
     n.cores <- parallel::detectCores() - 1
     if(n.iterations < n.cores){n.cores <- n.iterations}
-    my.cluster <- parallel::makeCluster(n.cores, type="FORK")
+
+    if(.Platform$OS.type == "windows"){
+      my.cluster <- parallel::makeCluster(n.cores, type="PSOCK")
+    } else {
+      my.cluster <- parallel::makeCluster(n.cores, type="FORK")
+    }
+
     doParallel::registerDoParallel(my.cluster)
 
   #exporting cluster variables
@@ -135,6 +141,7 @@ distanceMatrix <- function(sequences = NULL,
   } else {
     #replaces dopar (parallel) by do (serial)
     `%dopar%` <- foreach::`%do%`
+    on.exit(`%dopar%` <- foreach::`%dopar%`)
   }
 
   #parallelized loop
