@@ -29,7 +29,13 @@ leastCost <- function(least.cost.path = NULL, parallel.execution = TRUE){
     `%dopar%` <- foreach::`%dopar%`
     n.cores <- parallel::detectCores() - 1
     if(n.iterations < n.cores){n.cores <- n.iterations}
-    my.cluster <- parallel::makeCluster(n.cores, type="FORK")
+
+    if(.Platform$OS.type == "windows"){
+      my.cluster <- parallel::makeCluster(n.cores, type="PSOCK")
+    } else {
+      my.cluster <- parallel::makeCluster(n.cores, type="FORK")
+    }
+
     doParallel::registerDoParallel(my.cluster)
 
     #exporting cluster variables
@@ -41,6 +47,7 @@ leastCost <- function(least.cost.path = NULL, parallel.execution = TRUE){
   } else {
     #replaces dopar (parallel) by do (serial)
     `%dopar%` <- foreach::`%do%`
+    on.exit(`%dopar%` <- foreach::`%dopar%`)
   }
 
   #iterating through available elements
