@@ -105,7 +105,13 @@ psi <- function(least.cost = NULL,
     `%dopar%` <- foreach::`%dopar%`
     n.cores <- parallel::detectCores() - 1
     if(n.iterations < n.cores){n.cores <- n.iterations}
-    my.cluster <- parallel::makeCluster(n.cores, type="FORK")
+
+    if(.Platform$OS.type == "windows"){
+      my.cluster <- parallel::makeCluster(n.cores, type="PSOCK")
+    } else {
+      my.cluster <- parallel::makeCluster(n.cores, type="FORK")
+    }
+
     doParallel::registerDoParallel(my.cluster)
 
   #exporting cluster variables
@@ -118,6 +124,7 @@ psi <- function(least.cost = NULL,
   } else {
     #replaces dopar (parallel) by do (serial)
     `%dopar%` <- foreach::`%do%`
+    on.exit(`%dopar%` <- foreach::`%dopar%`)
   }
 
   #parallelized loop
